@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -10,18 +13,16 @@ import typing_extensions
 
 from typeguard import check_type
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_ecs._jsii
-import aws_cdk.aws_ssm._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
+import aws_cdk.integ_tests_alpha._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-fargate-ssmstringparameter",
-    "1.180.0",
+    "2.59.0",
     __name__[0:-6],
-    "aws-fargate-ssmstringparameter@1.180.0.jsii.tgz",
+    "aws-fargate-ssmstringparameter@2.59.0.jsii.tgz",
 )
 
 __all__ = [
